pub fn assert_alignment<T>(ptr: *const T)Expand description
Panics if ptr is not aligned to DEFAULTALIGN bytes.
Panics
Panics with a descriptive message when the pointer does not satisfy the default alignment requirement.
pub fn assert_alignment<T>(ptr: *const T)Panics if ptr is not aligned to DEFAULTALIGN bytes.
Panics with a descriptive message when the pointer does not satisfy the default alignment requirement.