HalModuleImpl

Trait HalModuleImpl 

pub unsafe trait HalModuleImpl<BE: Backend>: Backend {
    // Required method
    fn new(n: u64) -> Module<BE>;
}
Module construction extension point.

Safety

Implementations must return a module handle that is valid for the backend and ring degree, and uphold the backend safety contract.

Required Methods

fn new(n: u64) -> Module<BE>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors